@@ -1,5 +1,5 @@
 from django.template import Library, defaultfilters
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 register = Library()
 
